@@ -24,3 +24,6 @@ class TestLogView(unittest.TestCase):
     def test_invalid_loglevel(self):
         body = 'Error: too much ham'
         self.app.post('/clientlogs/spam/impossible', body, status=404)
+
+    def test_logger_name_colon(self):
+        self.app.post('/clientlogs/com.ludia::Test/error', status=200)
