@@ -25,7 +25,7 @@ class TestLogView(unittest.TestCase):
         from pyramid_restlogging.views import log_view
         req = DummyRequest()
         req.matchdict = {
-            'logger_name': 'com.ludia:Application',
+            'logger_name': 'com.ludia::Application',
             'log_level': 'debug',
             }
         req.body = 'beware of the dog.'
